#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-orphans
version:              0.1.1.0
visibility:           public
id:                   rio-orphans-0.1.1.0-IPMLjY9FTdE9SzGe3ktDos
key:                  rio-orphans-0.1.1.0-IPMLjY9FTdE9SzGe3ktDos
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  7350218dfcb9de12e2fcb82507410728
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-8.10.2/site-local/rio-orphans-0.1.1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/rio-orphans-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/rio-orphans-0.1.1.0
hs-libraries:         HSrio-orphans-0.1.1.0-IPMLjY9FTdE9SzGe3ktDos
depends:
    base-4.14.1.0 exceptions-0.10.4
    fast-logger-3.0.2-4brp8rjZ8ZTJd0WKKbI6MC
    monad-control-1.0.2.3-D0QtFvOGiobG7KTK5Cfhxz
    monad-logger-0.3.36-7Ivl5kcncUr1znklCaMQsw
    resourcet-1.2.4.2-E1PquPTZKgvLbHxPSs1hvZ
    rio-0.1.19.0-CZB73ftfFJVIFSmEs7cKYG
    transformers-base-0.4.5.2-5NQt00osHIwIugRpgg1tUI

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

